@@ -153,8 +153,6 @@ struct _ThunarUcaModel
 {
   GObject __parent__;
 
-  GtkIconFactory *icon_factory;
-
   GList          *items;
   gint            stamp;
 };
@@ -254,12 +252,6 @@ thunar_uca_model_init (ThunarUcaModel *uca_model)
   GError *error = NULL;
   gchar  *filename;
 
-  /* allocate a new icon factory for our action icons
-   * and add it to the default icon factories
-   */
-  uca_model->icon_factory = gtk_icon_factory_new ();
-  gtk_icon_factory_add_default (uca_model->icon_factory);
-
   /* generate a unique stamp */
   uca_model->stamp = g_random_int ();
 
@@ -286,10 +278,6 @@ thunar_uca_model_finalize (GObject *object)
 {
   ThunarUcaModel *uca_model = THUNAR_UCA_MODEL (object);
 
-  /* drop our icon factory */
-  gtk_icon_factory_remove_default (uca_model->icon_factory);
-  g_object_unref (G_OBJECT (uca_model->icon_factory));
-
   /* release all items */
   g_list_free_full (uca_model->items, thunar_uca_model_item_free);
 
@@ -850,7 +838,8 @@ end_element_handler (GMarkupParseContext *context,
                                    parser->command->str,
                                    parser->startup_notify,
                                    parser->patterns->str,
-                                   parser->types);
+                                   parser->types,
+                                   0, 0);
 
           /* check if a new id should've been generated */
           if (exo_str_is_empty (parser->unique_id->str))
@@ -1000,9 +989,9 @@ thunar_uca_model_get_unique_id (void)
  * thunar_uca_model_get_default:
  *
  * Returns a reference to the default shared
- * #ThunarUcaModel instance. The caller is 
+ * #ThunarUcaModel instance. The caller is
  * responsible to free the returned instance
- * using g_object_unref() when no longer 
+ * using g_object_unref() when no longer
  * needed.
  *
  * Return value: a reference to the default
@@ -1319,11 +1308,14 @@ thunar_uca_model_update (ThunarUcaModel *uca_model,
                          const gchar    *command,
                          gboolean        startup_notify,
                          const gchar    *patterns,
-                         ThunarUcaTypes  types)
+                         ThunarUcaTypes  types,
+                         guint           accel_key,
+                         GdkModifierType accel_mods)
 {
   ThunarUcaModelItem *item;
   GtkTreePath        *path;
   guint               n, m;
+  gchar              *accel_path;
 
   g_return_if_fail (THUNAR_UCA_IS_MODEL (uca_model));
   g_return_if_fail (iter->stamp == uca_model->stamp);
@@ -1374,6 +1366,14 @@ thunar_uca_model_update (ThunarUcaModel *uca_model,
   path = gtk_tree_model_get_path (GTK_TREE_MODEL (uca_model), iter);
   gtk_tree_model_row_changed (GTK_TREE_MODEL (uca_model), path, iter);
   gtk_tree_path_free (path);
+
+  /* update accelerator */
+  if (accel_key > 0)
+    {
+      accel_path = g_strdup_printf ("<Actions>/ThunarActions/uca-action-%s", item->unique_id);
+      gtk_accel_map_change_entry (accel_path, accel_key, accel_mods, TRUE);
+      g_free (accel_path);
+    }
 }
 
 
