@@ -140,6 +140,11 @@ twp_provider_get_file_menu_items (ThunarxMenuProvider *menu_provider,
   GdkScreen       *gdk_screen = gdk_screen_get_default();
   gint             xscreen = gdk_x11_screen_get_screen_number(gdk_screen);
 
+  if(g_strcmp0 (g_getenv ("XDG_SESSION_TYPE"), "wayland") == 0)
+    {
+      return items; // wayland crashes on "gdk_x11_get_default_xdisplay"
+    }
+
   main_window = window;
   desktop_type = DESKTOP_TYPE_NONE;
 
