@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -77,8 +77,8 @@ static gboolean     thunar_abstract_icon_view_button_press_event    (ExoIconView
 static gboolean     thunar_abstract_icon_view_button_release_event  (ExoIconView                  *view,
                                                                      GdkEventButton               *event,
                                                                      ThunarAbstractIconView       *abstract_icon_view);
-static gboolean     thunar_abstract_icon_view_expose_event          (ExoIconView                  *view,
-                                                                     GdkEventExpose               *event,
+static gboolean     thunar_abstract_icon_view_draw                  (ExoIconView                  *view,
+                                                                     cairo_t                      *cr,
                                                                      ThunarAbstractIconView       *abstract_icon_view);
 static gboolean     thunar_abstract_icon_view_key_press_event       (ExoIconView                  *view,
                                                                      GdkEventKey                  *event,
@@ -224,11 +224,13 @@ thunar_abstract_icon_view_init (ThunarAbstractIconView *abstract_icon_view)
                                  "file", THUNAR_COLUMN_FILE);
 
   /* add the name renderer */
-  g_object_set (G_OBJECT (THUNAR_STANDARD_VIEW (abstract_icon_view)->name_renderer), "follow-state", TRUE, NULL);
+  /*FIXME text prelit*/
+  /*g_object_set (G_OBJECT (THUNAR_STANDARD_VIEW (abstract_icon_view)->name_renderer), "follow-state", TRUE, NULL);*/
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (view), THUNAR_STANDARD_VIEW (abstract_icon_view)->name_renderer, TRUE);
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (view), THUNAR_STANDARD_VIEW (abstract_icon_view)->name_renderer,
                                  "text", THUNAR_COLUMN_NAME);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   /* setup the abstract icon view actions */
   gtk_action_group_add_actions (THUNAR_STANDARD_VIEW (abstract_icon_view)->action_group,
                                 action_entries, G_N_ELEMENTS (action_entries),
@@ -239,11 +241,16 @@ thunar_abstract_icon_view_init (ThunarAbstractIconView *abstract_icon_view)
   gtk_action_group_add_radio_actions (THUNAR_STANDARD_VIEW (abstract_icon_view)->action_group, order_action_entries,
                                       G_N_ELEMENTS (order_action_entries), GTK_SORT_ASCENDING,
                                       G_CALLBACK (thunar_abstract_icon_view_action_sort), abstract_icon_view);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   /* we need to listen to sort column changes to sync the menu items */
   g_signal_connect (G_OBJECT (THUNAR_STANDARD_VIEW (abstract_icon_view)->model), "sort-column-changed",
                     G_CALLBACK (thunar_abstract_icon_view_sort_column_changed), abstract_icon_view);
   thunar_abstract_icon_view_sort_column_changed (GTK_TREE_SORTABLE (THUNAR_STANDARD_VIEW (abstract_icon_view)->model), abstract_icon_view);
+
+  /* update the icon view on size-allocate events */
+  g_signal_connect_swapped (G_OBJECT (abstract_icon_view), "size-allocate",
+                            G_CALLBACK (gtk_widget_queue_resize), view);
 }
 
 
@@ -259,8 +266,8 @@ thunar_abstract_icon_view_style_set (GtkWidget *widget,
   gtk_widget_style_get (widget, "column-spacing", &column_spacing, "row-spacing", &row_spacing, NULL);
 
   /* apply the column/row spacing to the icon view */
-  exo_icon_view_set_column_spacing (EXO_ICON_VIEW (GTK_BIN (widget)->child), column_spacing);
-  exo_icon_view_set_row_spacing (EXO_ICON_VIEW (GTK_BIN (widget)->child), row_spacing);
+  exo_icon_view_set_column_spacing (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (widget))), column_spacing);
+  exo_icon_view_set_row_spacing (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (widget))), row_spacing);
 
   /* call the parent handler */
   (*GTK_WIDGET_CLASS (thunar_abstract_icon_view_parent_class)->style_set) (widget, previous_style);
@@ -275,8 +282,10 @@ thunar_abstract_icon_view_connect_ui_manager (ThunarStandardView *standard_view,
   ThunarAbstractIconView *abstract_icon_view = THUNAR_ABSTRACT_ICON_VIEW (standard_view);
   GError                 *error = NULL;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   abstract_icon_view->priv->ui_merge_id = gtk_ui_manager_add_ui_from_string (ui_manager, thunar_abstract_icon_view_ui,
                                                                              thunar_abstract_icon_view_ui_length, &error);
+G_GNUC_END_IGNORE_DEPRECATIONS
   if (G_UNLIKELY (abstract_icon_view->priv->ui_merge_id == 0))
     {
       g_error ("Failed to merge ThunarAbstractIconView menus: %s", error->message);
@@ -290,7 +299,9 @@ static void
 thunar_abstract_icon_view_disconnect_ui_manager (ThunarStandardView *standard_view,
                                                  GtkUIManager       *ui_manager)
 {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   gtk_ui_manager_remove_ui (ui_manager, THUNAR_ABSTRACT_ICON_VIEW (standard_view)->priv->ui_merge_id);
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 
@@ -298,7 +309,7 @@ thunar_abstract_icon_view_disconnect_ui_manager (ThunarStandardView *standard_vi
 static GList*
 thunar_abstract_icon_view_get_selected_items (ThunarStandardView *standard_view)
 {
-  return exo_icon_view_get_selected_items (EXO_ICON_VIEW (GTK_BIN (standard_view)->child));
+  return exo_icon_view_get_selected_items (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))));
 }
 
 
@@ -307,7 +318,7 @@ static void
 thunar_abstract_icon_view_select_all (ThunarStandardView *standard_view)
 {
   _thunar_return_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view));
-  exo_icon_view_select_all (EXO_ICON_VIEW (GTK_BIN (standard_view)->child));
+  exo_icon_view_select_all (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))));
 }
 
 
@@ -316,7 +327,7 @@ static void
 thunar_abstract_icon_view_unselect_all (ThunarStandardView *standard_view)
 {
   _thunar_return_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view));
-  exo_icon_view_unselect_all (EXO_ICON_VIEW (GTK_BIN (standard_view)->child));
+  exo_icon_view_unselect_all (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))));
 }
 
 
@@ -325,7 +336,7 @@ static void
 thunar_abstract_icon_view_selection_invert (ThunarStandardView *standard_view)
 {
   _thunar_return_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view));
-  exo_icon_view_selection_invert (EXO_ICON_VIEW (GTK_BIN (standard_view)->child));
+  exo_icon_view_selection_invert (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))));
 }
 
 
@@ -335,7 +346,7 @@ thunar_abstract_icon_view_select_path (ThunarStandardView *standard_view,
                                        GtkTreePath        *path)
 {
   _thunar_return_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view));
-  exo_icon_view_select_path (EXO_ICON_VIEW (GTK_BIN (standard_view)->child), path);
+  exo_icon_view_select_path (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))), path);
 }
 
 
@@ -350,14 +361,14 @@ thunar_abstract_icon_view_set_cursor (ThunarStandardView *standard_view,
   _thunar_return_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view));
 
   /* make sure the name renderer is editable */
-  mode = standard_view->name_renderer->mode;
-  standard_view->name_renderer->mode = GTK_CELL_RENDERER_MODE_EDITABLE;
+  g_object_get ( G_OBJECT (standard_view->name_renderer), "mode", &mode, NULL);
+  g_object_set ( G_OBJECT (standard_view->name_renderer), "mode", GTK_CELL_RENDERER_MODE_EDITABLE, NULL);
 
   /* tell the abstract_icon view to start editing the given item */
-  exo_icon_view_set_cursor (EXO_ICON_VIEW (GTK_BIN (standard_view)->child), path, standard_view->name_renderer, start_editing);
+  exo_icon_view_set_cursor (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))), path, standard_view->name_renderer, start_editing);
 
   /* reset the name renderer mode */
-  standard_view->name_renderer->mode = mode;
+  g_object_set (G_OBJECT (standard_view->name_renderer), "mode", mode, NULL);
 }
 
 
@@ -370,7 +381,7 @@ thunar_abstract_icon_view_scroll_to_path (ThunarStandardView *standard_view,
                                           gfloat              col_align)
 {
   _thunar_return_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view));
-  exo_icon_view_scroll_to_path (EXO_ICON_VIEW (GTK_BIN (standard_view)->child), path, use_align, row_align, col_align);
+  exo_icon_view_scroll_to_path (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))), path, use_align, row_align, col_align);
 }
 
 
@@ -381,7 +392,7 @@ thunar_abstract_icon_view_get_path_at_pos (ThunarStandardView *standard_view,
                                            gint                y)
 {
   _thunar_return_val_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view), NULL);
-  return exo_icon_view_get_path_at_pos (EXO_ICON_VIEW (GTK_BIN (standard_view)->child), x, y);
+  return exo_icon_view_get_path_at_pos (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))), x, y);
 }
 
 
@@ -392,7 +403,7 @@ thunar_abstract_icon_view_get_visible_range (ThunarStandardView *standard_view,
                                              GtkTreePath       **end_path)
 {
   _thunar_return_val_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view), FALSE);
-  return exo_icon_view_get_visible_range (EXO_ICON_VIEW (GTK_BIN (standard_view)->child), start_path, end_path);
+  return exo_icon_view_get_visible_range (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))), start_path, end_path);
 }
 
 
@@ -402,7 +413,7 @@ thunar_abstract_icon_view_highlight_path (ThunarStandardView *standard_view,
                                           GtkTreePath        *path)
 {
   _thunar_return_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (standard_view));
-  exo_icon_view_set_drag_dest_item (EXO_ICON_VIEW (GTK_BIN (standard_view)->child), path, EXO_ICON_VIEW_DROP_INTO);
+  exo_icon_view_set_drag_dest_item (EXO_ICON_VIEW (gtk_bin_get_child (GTK_BIN (standard_view))), path, EXO_ICON_VIEW_DROP_INTO);
 }
 
 
@@ -410,6 +421,7 @@ thunar_abstract_icon_view_highlight_path (ThunarStandardView *standard_view,
 static GtkAction*
 thunar_abstract_icon_view_gesture_action (ThunarAbstractIconView *abstract_icon_view)
 {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   if (abstract_icon_view->priv->gesture_start_y - abstract_icon_view->priv->gesture_current_y > 40
       && ABS (abstract_icon_view->priv->gesture_start_x - abstract_icon_view->priv->gesture_current_x) < 40)
     {
@@ -430,6 +442,7 @@ thunar_abstract_icon_view_gesture_action (ThunarAbstractIconView *abstract_icon_
     {
       return gtk_ui_manager_get_action (THUNAR_STANDARD_VIEW (abstract_icon_view)->ui_manager, "/main-menu/view-menu/reload");
     }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   return NULL;
 }
@@ -444,6 +457,7 @@ thunar_abstract_icon_view_action_sort (GtkAction          *action,
   GtkSortType order;
   gint        column;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   /* query the new sort column id */
   action = gtk_action_group_get_action (standard_view->action_group, "sort-by-name");
   column = gtk_radio_action_get_current_value (GTK_RADIO_ACTION (action));
@@ -451,6 +465,7 @@ thunar_abstract_icon_view_action_sort (GtkAction          *action,
   /* query the new sort order */
   action = gtk_action_group_get_action (standard_view->action_group, "sort-ascending");
   order = gtk_radio_action_get_current_value (GTK_RADIO_ACTION (action));
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   /* apply the new settings */
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (standard_view->model), column, order);
@@ -508,14 +523,14 @@ thunar_abstract_icon_view_button_press_event (ExoIconView            *view,
            * to make sure that the folder context menu is opened.
            */
           exo_icon_view_unselect_all (view);
-      
+
           /* open the context menu */
-          thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (abstract_icon_view), event->button, event->time);
+          thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (abstract_icon_view));
         }
 
       return TRUE;
     }
-  else if ((event->type == GDK_BUTTON_PRESS || event->type == GDK_2BUTTON_PRESS) && event->button == 2)
+  else if (event->type == GDK_BUTTON_PRESS && event->button == 2)
     {
       /* unselect all currently selected items */
       exo_icon_view_unselect_all (view);
@@ -526,43 +541,30 @@ thunar_abstract_icon_view_button_press_event (ExoIconView            *view,
           /* select only the path to the item on which the user clicked */
           exo_icon_view_select_path (view, path);
 
-          /* if the event was a double-click or we are in single-click mode, then
-           * we'll open the file or folder (folder's are opened in new windows)
-           */
-          if (G_LIKELY (event->type == GDK_2BUTTON_PRESS || exo_icon_view_get_single_click (view)))
+          /* determine the file for the path */
+          gtk_tree_model_get_iter (GTK_TREE_MODEL (THUNAR_STANDARD_VIEW (abstract_icon_view)->model), &iter, path);
+          file = thunar_list_model_get_file (THUNAR_STANDARD_VIEW (abstract_icon_view)->model, &iter);
+          if (G_LIKELY (file != NULL) && thunar_file_is_directory (file))
             {
-              /* determine the file for the path */
-              gtk_tree_model_get_iter (GTK_TREE_MODEL (THUNAR_STANDARD_VIEW (abstract_icon_view)->model), &iter, path);
-              file = thunar_list_model_get_file (THUNAR_STANDARD_VIEW (abstract_icon_view)->model, &iter);
-              if (G_LIKELY (file != NULL))
-                {
-                  /* determine the action to perform depending on the type of the file */
-                  if (thunar_file_is_directory (file))
-                    {
-                      /* lookup setting if we should open in a tab or a window */
-                      preferences = thunar_preferences_get ();
-                      g_object_get (preferences, "misc-middle-click-in-tab", &in_tab, NULL);
-                      g_object_unref (preferences);
+              /* lookup setting if we should open in a tab or a window */
+              preferences = thunar_preferences_get ();
+              g_object_get (preferences, "misc-middle-click-in-tab", &in_tab, NULL);
+              g_object_unref (preferences);
 
-                      /* holding ctrl inverts the action */
-                      if ((event->state & GDK_CONTROL_MASK) != 0)
-                        in_tab = !in_tab;
+              /* holding ctrl inverts the action */
+              if ((event->state & GDK_CONTROL_MASK) != 0)
+                  in_tab = !in_tab;
+              action_name = in_tab ? "open-in-new-tab" : "open-in-new-window";
 
-                      action_name = in_tab ? "open-in-new-tab" : "open-in-new-window";
-                    }
-                  else
-                    {
-                      action_name = "open";
-                    }
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+              /* emit the action */
+              action = thunar_gtk_ui_manager_get_action_by_name (THUNAR_STANDARD_VIEW (abstract_icon_view)->ui_manager, action_name);
+              if (G_LIKELY (action != NULL))
+                  gtk_action_activate (action);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
-                  /* emit the action */
-                  action = thunar_gtk_ui_manager_get_action_by_name (THUNAR_STANDARD_VIEW (abstract_icon_view)->ui_manager, action_name);
-                  if (G_LIKELY (action != NULL))
-                    gtk_action_activate (action);
-
-                  /* release the file reference */
-                  g_object_unref (G_OBJECT (file));
-                }
+              /* release the file reference */
+              g_object_unref (G_OBJECT (file));
             }
 
           /* cleanup */
@@ -572,8 +574,8 @@ thunar_abstract_icon_view_button_press_event (ExoIconView            *view,
         {
           abstract_icon_view->priv->gesture_start_x = abstract_icon_view->priv->gesture_current_x = event->x;
           abstract_icon_view->priv->gesture_start_y = abstract_icon_view->priv->gesture_current_y = event->y;
-          abstract_icon_view->priv->gesture_expose_id = g_signal_connect_after (G_OBJECT (view), "expose-event",
-                                                                                G_CALLBACK (thunar_abstract_icon_view_expose_event),
+          abstract_icon_view->priv->gesture_expose_id = g_signal_connect_after (G_OBJECT (view), "draw",
+                                                                                G_CALLBACK (thunar_abstract_icon_view_draw),
                                                                                 G_OBJECT (abstract_icon_view));
           abstract_icon_view->priv->gesture_motion_id = g_signal_connect (G_OBJECT (view), "motion-notify-event",
                                                                           G_CALLBACK (thunar_abstract_icon_view_motion_notify_event),
@@ -607,8 +609,10 @@ thunar_abstract_icon_view_button_release_event (ExoIconView            *view,
 
   /* run the selected action (if any) */
   action = thunar_abstract_icon_view_gesture_action (abstract_icon_view);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   if (G_LIKELY (action != NULL))
     gtk_action_activate (action);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   /* unregister the "expose-event" handler */
   g_signal_handler_disconnect (G_OBJECT (view), abstract_icon_view->priv->gesture_expose_id);
@@ -631,16 +635,13 @@ thunar_abstract_icon_view_button_release_event (ExoIconView            *view,
 
 
 static gboolean
-thunar_abstract_icon_view_expose_event (ExoIconView            *view,
-                                        GdkEventExpose         *event,
-                                        ThunarAbstractIconView *abstract_icon_view)
+thunar_abstract_icon_view_draw (ExoIconView            *view,
+                                cairo_t                *cr,
+                                ThunarAbstractIconView *abstract_icon_view)
 {
-  GtkIconSet *stock_icon_set;
   GtkAction  *action = NULL;
-  GdkPixbuf  *stock_icon = NULL;
-  gchar      *stock_id;
-  GdkColor    bg;
-  cairo_t    *cr;
+  GdkPixbuf  *gesture_icon = NULL;
+  gchar      *icon_name;
   gint        x, y;
 
   _thunar_return_val_if_fail (EXO_IS_ICON_VIEW (view), FALSE);
@@ -649,56 +650,44 @@ thunar_abstract_icon_view_expose_event (ExoIconView            *view,
   _thunar_return_val_if_fail (abstract_icon_view->priv->gesture_motion_id > 0, FALSE);
   _thunar_return_val_if_fail (abstract_icon_view->priv->gesture_release_id > 0, FALSE);
 
-  /* create the cairo context (is already clipped) */
-  cr = gdk_cairo_create (event->window);
-
   /* shade the abstract_icon view content while performing mouse gestures */
-  bg = GTK_WIDGET (view)->style->base[GTK_STATE_NORMAL];
-  cairo_set_source_rgba (cr, bg.red / 65535.0, bg.green / 65535.0, bg.blue / 65535.0, 0.7);
+  cairo_set_source_rgba (cr, 1, 1, 1, 0.7);
   cairo_paint (cr);
 
   /* determine the gesture action */
   action = thunar_abstract_icon_view_gesture_action (abstract_icon_view);
   if (G_LIKELY (action != NULL))
     {
-      /* determine the stock abstract_icon for the action */
-      g_object_get (G_OBJECT (action), "stock-id", &stock_id, NULL);
-
-      /* lookup the abstract_icon set for the stock abstract_icon */
-      stock_icon_set = gtk_style_lookup_icon_set (GTK_WIDGET (view)->style, stock_id);
-      if (G_LIKELY (stock_icon_set != NULL))
-        {
-          stock_icon = gtk_icon_set_render_icon (stock_icon_set, GTK_WIDGET (view)->style,
-                                                 gtk_widget_get_direction (GTK_WIDGET (view)),
-                                                 gtk_action_is_sensitive (action) ? 0 : GTK_STATE_INSENSITIVE,
-                                                 GTK_ICON_SIZE_DND, GTK_WIDGET (view), NULL);
-        }
+      /* get the icon-name for the action */
+      g_object_get (G_OBJECT (action), "icon-name", &icon_name, NULL);
 
+      gesture_icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default(),
+                                               icon_name,
+                                               32,
+                                               GTK_ICON_LOOKUP_FORCE_SIZE,
+                                               NULL);
       /* draw the rendered icon */
-      if (G_LIKELY (stock_icon != NULL))
+      if (G_LIKELY (gesture_icon != NULL))
         {
           /* x/y position of the icon */
-          x = abstract_icon_view->priv->gesture_start_x - gdk_pixbuf_get_width (stock_icon) / 2;
-          y = abstract_icon_view->priv->gesture_start_y - gdk_pixbuf_get_height (stock_icon) / 2;
+          x = abstract_icon_view->priv->gesture_start_x - gdk_pixbuf_get_width (gesture_icon) / 2;
+          y = abstract_icon_view->priv->gesture_start_y - gdk_pixbuf_get_height (gesture_icon) / 2;
 
-          /* render the stock abstract_icon into the abstract_icon view window */
-          gdk_cairo_set_source_pixbuf (cr, stock_icon, x, y);
+          /* render the icon into the abstract_icon view window */
+          gdk_cairo_set_source_pixbuf (cr, gesture_icon, x, y);
           cairo_rectangle (cr, x, y,
-                           gdk_pixbuf_get_width (stock_icon),
-                           gdk_pixbuf_get_height (stock_icon));
+                           gdk_pixbuf_get_width (gesture_icon),
+                           gdk_pixbuf_get_height (gesture_icon));
           cairo_fill (cr);
 
           /* release the stock abstract_icon */
-          g_object_unref (G_OBJECT (stock_icon));
+          g_object_unref (G_OBJECT (gesture_icon));
         }
 
       /* release the stock id */
-      g_free (stock_id);
+      g_free (icon_name);
     }
 
-  /* destroy context */
-  cairo_destroy (cr);
-
   return FALSE;
 }
 
@@ -710,9 +699,9 @@ thunar_abstract_icon_view_key_press_event (ExoIconView            *view,
                                            ThunarAbstractIconView *abstract_icon_view)
 {
   /* popup context menu if "Menu" or "<Shift>F10" is pressed */
-  if (event->keyval == GDK_Menu || ((event->state & GDK_SHIFT_MASK) != 0 && event->keyval == GDK_F10))
+  if (event->keyval == GDK_KEY_Menu || ((event->state & GDK_SHIFT_MASK) != 0 && event->keyval == GDK_KEY_F10))
     {
-      thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (abstract_icon_view), 0, event->time);
+      thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (abstract_icon_view));
       return TRUE;
     }
 
@@ -772,10 +761,12 @@ thunar_abstract_icon_view_item_activated (ExoIconView            *view,
   exo_icon_view_unselect_all (view);
   exo_icon_view_select_path (view, path);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   /* emit the "open" action */
   action = thunar_gtk_ui_manager_get_action_by_name (THUNAR_STANDARD_VIEW (abstract_icon_view)->ui_manager, "open");
   if (G_LIKELY (action != NULL))
     gtk_action_activate (action);
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 
@@ -790,6 +781,7 @@ thunar_abstract_icon_view_sort_column_changed (GtkTreeSortable        *sortable,
 
   if (gtk_tree_sortable_get_sort_column_id (sortable, &column, &order))
     {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       /* apply the new sort column */
       action = gtk_action_group_get_action (THUNAR_STANDARD_VIEW (abstract_icon_view)->action_group, "sort-by-name");
       gtk_radio_action_set_current_value (GTK_RADIO_ACTION (action), column);
@@ -797,6 +789,7 @@ thunar_abstract_icon_view_sort_column_changed (GtkTreeSortable        *sortable,
       /* apply the new sort order */
       action = gtk_action_group_get_action (THUNAR_STANDARD_VIEW (abstract_icon_view)->action_group, "sort-ascending");
       gtk_radio_action_set_current_value (GTK_RADIO_ACTION (action), order);
+G_GNUC_END_IGNORE_DEPRECATIONS
     }
 }
 
@@ -808,8 +801,7 @@ thunar_abstract_icon_view_zoom_level_changed (ThunarAbstractIconView *abstract_i
   _thunar_return_if_fail (THUNAR_IS_ABSTRACT_ICON_VIEW (abstract_icon_view));
 
   /* we use the same trick as with ThunarDetailsView here, simply because its simple :-) */
-  gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (GTK_BIN (abstract_icon_view)->child),
+  gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (gtk_bin_get_child (GTK_BIN (abstract_icon_view))),
                                       THUNAR_STANDARD_VIEW (abstract_icon_view)->icon_renderer,
                                       NULL, NULL, NULL);
 }
-
