@@ -117,7 +117,10 @@ static void           thunar_application_dbus_acquired_cb       (GDBusConnection
 static void           thunar_application_name_acquired_cb       (GDBusConnection        *connection,
                                                                  const gchar            *name,
                                                                  gpointer                user_data);
-static void           thunar_application_dbus_name_lost_cb      (GDBusConnection        *connection,
+static void           thunar_application_dbus_name_lost_crit_cb (GDBusConnection        *connection,
+                                                                 const gchar            *name,
+                                                                 gpointer                user_data);
+static void           thunar_application_dbus_name_lost_warn_cb (GDBusConnection        *connection,
                                                                  const gchar            *name,
                                                                  gpointer                user_data);
 static void           thunar_application_dbus_init              (ThunarApplication      *application);
@@ -208,7 +211,8 @@ struct _ThunarApplication
 
   GList                 *files_to_launch;
 
-  guint                  dbus_owner_id;
+  guint                  dbus_owner_id_xfce;
+  guint                  dbus_owner_id_fdo;
 };
 
 
@@ -304,7 +308,7 @@ thunar_application_name_acquired_cb (GDBusConnection *connection,
 
 
 static void
-thunar_application_dbus_name_lost_cb (GDBusConnection *connection,
+thunar_application_dbus_name_lost_crit_cb (GDBusConnection *connection,
                                       const gchar     *name,
                                       gpointer         user_data)
 {
@@ -315,6 +319,16 @@ thunar_application_dbus_name_lost_cb (GDBusConnection *connection,
 
 
 
+static void
+thunar_application_dbus_name_lost_warn_cb (GDBusConnection *connection,
+                                      const gchar     *name,
+                                      gpointer         user_data)
+{
+  g_warning (_("Name '%s' lost on the message dbus."), name);
+}
+
+
+
 /* TODO: [GTK3 Port] Check if there's a cleaner way to register */
 /* this extra dbus name (besides org.xfce.Thunar) */
 static void
@@ -324,14 +338,23 @@ thunar_application_dbus_init (ThunarApplication *application)
     if (geteuid() == 0)
       return;
 
-    application->dbus_owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
-                               "org.xfce.FileManager",
-                               G_BUS_NAME_OWNER_FLAGS_NONE,
-                               thunar_application_dbus_acquired_cb,
-                               thunar_application_name_acquired_cb,
-                               thunar_application_dbus_name_lost_cb,
-                               application,
-                               NULL);
+    application->dbus_owner_id_xfce = g_bus_own_name (G_BUS_TYPE_SESSION,
+                                      "org.xfce.FileManager",
+                                      G_BUS_NAME_OWNER_FLAGS_NONE,
+                                      thunar_application_dbus_acquired_cb,
+                                      thunar_application_name_acquired_cb,
+                                      thunar_application_dbus_name_lost_crit_cb,
+                                      application,
+                                      NULL);
+
+    application->dbus_owner_id_fdo = g_bus_own_name (G_BUS_TYPE_SESSION,
+                                     "org.freedesktop.FileManager1",
+                                     G_BUS_NAME_OWNER_FLAGS_NONE,
+                                     thunar_application_dbus_acquired_cb,
+                                     thunar_application_name_acquired_cb,
+                                     thunar_application_dbus_name_lost_warn_cb,
+                                     application,
+                                     NULL);
 }
 
 
@@ -359,13 +382,13 @@ thunar_application_startup (GApplication *gapp)
                     G_CALLBACK (thunar_application_uevent), application);
 #endif
 
-  /* connect to the session manager */
-  application->session_client = thunar_session_client_new (opt_sm_client_id);
-
   thunar_application_dbus_init (application);
 
   G_APPLICATION_CLASS (thunar_application_parent_class)->startup (gapp);
 
+  /* connect to the session manager */
+  application->session_client = thunar_session_client_new (opt_sm_client_id);
+
   /* TODO: how do accel maps integrate with GAction/GMenu? Using GtkAction for now */
   /* check if we have a saved accel map */
   path = xfce_resource_lookup (XFCE_RESOURCE_CONFIG, ACCEL_MAP_PATH);
@@ -581,12 +604,16 @@ thunar_application_load_css (void)
 
   css_provider = gtk_css_provider_new ();
 
-                                                 /* For the pathbar-buttons any margin looks ugly*/
-  gtk_css_provider_load_from_data (css_provider, ".path-bar-button { margin-right: 0; }"
-
-                                                 /* remove extra border between side pane and view */
-                                                 ".shortcuts-pane { border-right-width: 0px; }"
-                                                 ".standard-view { border-left-width: 0px; }", -1, NULL);
+  gtk_css_provider_load_from_data (css_provider,
+    /* for the pathbar-buttons any margin looks ugly*/
+    ".path-bar-button { margin-right: 0; }"
+    /* remove extra border between side pane and view */
+    ".shortcuts-pane { border-right-width: 0px; }"
+    /* add missing top border to side pane */
+    ".shortcuts-pane { border-top-style: solid; }"
+    /* make border thicker during DnD */
+    ".standard-view { border-left-width: 0px; }"
+    ".standard-view:drop(active) { border-width: 2px; }", -1, NULL);
   screen = gdk_screen_get_default ();
   gtk_style_context_add_provider_for_screen (screen, GTK_STYLE_PROVIDER (css_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   g_object_unref (css_provider);
@@ -1100,6 +1127,11 @@ thunar_application_quit (ThunarApplication *application)
   _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
 
   thunar_application_set_daemon(application, FALSE);
+
+  /* For some unknown reason we need to close all open thunar windows before quit */
+  /* Otherwise thunar will hangup on quit and thunar_application_shutdown will not be called */
+  thunar_application_close_all_windows (application);
+
   gtk_main_quit ();
 }
 
@@ -1149,6 +1181,28 @@ thunar_application_set_daemon (ThunarApplication *application,
 
 
 
+/**
+ * thunar_application_close_all_windows:
+ * @application : a #ThunarApplication.
+ *
+ * Closes all #ThunarWindows currently handled by @application.
+ **/
+void
+thunar_application_close_all_windows (ThunarApplication *application)
+{
+  GList *gtk_windows, *lp;
+
+  _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
+
+  gtk_windows = gtk_application_get_windows (GTK_APPLICATION (application));
+
+  for (lp = gtk_windows; lp != NULL; lp = lp->next)
+    if (G_LIKELY (THUNAR_IS_WINDOW (lp->data)))
+      gtk_window_close (lp->data);
+}
+
+
+
 /**
  * thunar_application_get_windows:
  * @application : a #ThunarApplication.
@@ -1233,14 +1287,15 @@ thunar_application_take_window (ThunarApplication *application,
 
 /**
  * thunar_application_open_window:
- * @application    : a #ThunarApplication.
- * @directory      : the directory to open.
- * @screen         : the #GdkScreen on which to open the window or %NULL
- *                   to open on the default screen.
- * @startup_id     : startup id from startup notification passed along
- *                   with dbus to make focus stealing work properly.
+ * @application      : a #ThunarApplication.
+ * @directory        : the directory to open.
+ * @screen           : the #GdkScreen on which to open the window or %NULL
+ *                     to open on the default screen.
+ * @startup_id       : startup id from startup notification passed along
+ *                     with dbus to make focus stealing work properly.
+ * @force_new_window : set this flag to force a new window, even if misc-open-new-window-as-tab is set
  *
- * Opens a new #ThunarWindow for @application, displaying the
+ * Opens a new #ThunarWindow (or tab if preferred) for @application, displaying the
  * given @directory.
  *
  * Return value: the newly allocated #ThunarWindow.
@@ -1249,10 +1304,13 @@ GtkWidget*
 thunar_application_open_window (ThunarApplication *application,
                                 ThunarFile        *directory,
                                 GdkScreen         *screen,
-                                const gchar       *startup_id)
+                                const gchar       *startup_id,
+                                gboolean           force_new_window)
 {
+  GList*     list;
   GtkWidget *window;
   gchar     *role;
+  gboolean   open_new_window_as_tab;
 
   _thunar_return_val_if_fail (THUNAR_IS_APPLICATION (application), NULL);
   _thunar_return_val_if_fail (directory == NULL || THUNAR_IS_FILE (directory), NULL);
@@ -1261,6 +1319,25 @@ thunar_application_open_window (ThunarApplication *application,
   if (G_UNLIKELY (screen == NULL))
     screen = gdk_screen_get_default ();
 
+  /* open as tab instead, if preferred */
+  g_object_get (G_OBJECT (application->preferences), "misc-open-new-window-as-tab", &open_new_window_as_tab, NULL);
+  if (G_UNLIKELY (!force_new_window && open_new_window_as_tab))
+    {
+      list = thunar_application_get_windows (application);
+      if (list != NULL)  
+        {
+          /* this will be the topmost Window */
+          list = g_list_last (list);
+
+          if (directory != NULL)
+              thunar_window_notebook_insert (THUNAR_WINDOW (list->data), directory);
+          
+          /* bring the window to front */
+          gtk_window_present (list->data);
+          return list->data;
+        }
+    }
+
   /* generate a unique role for the new window (for session management) */
   role = g_strdup_printf ("Thunar-%u-%u", (guint) time (NULL), (guint) g_random_int ());
 
@@ -1858,7 +1935,7 @@ thunar_application_copy_to (ThunarApplication *application,
   _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
 
   /* launch the operation */
-  thunar_application_launch (application, parent, "stock_folder-copy",
+  thunar_application_launch (application, parent, "edit-copy",
                              _("Copying files..."), thunar_io_jobs_copy_files,
                              source_file_list, target_file_list, new_files_closure);
 }
@@ -1899,7 +1976,7 @@ thunar_application_copy_into (ThunarApplication *application,
    g_free (display_name);
 
   /* collect the target files and launch the job */
-  thunar_application_collect_and_launch (application, parent, "stock_folder-copy",
+  thunar_application_collect_and_launch (application, parent, "edit-copy",
                                          title, thunar_io_jobs_copy_files,
                                          source_file_list, target_file,
                                          new_files_closure);
