@@ -897,19 +897,45 @@ thunar_details_view_columns_changed (ThunarColumnModel *column_model,
 
 
 
+static gboolean
+thunar_details_view_zoom_level_changed_reload_fixed_columns (gpointer data)
+{
+  ThunarDetailsView *details_view = data;
+  _thunar_return_val_if_fail (THUNAR_IS_DETAILS_VIEW (details_view), FALSE);
+
+  thunar_details_view_set_fixed_columns (details_view, TRUE);
+  return FALSE;
+}
+
+
+
 static void
 thunar_details_view_zoom_level_changed (ThunarDetailsView *details_view)
 {
   ThunarColumn column;
+  gboolean     fixed_columns_used = FALSE;
 
   _thunar_return_if_fail (THUNAR_IS_DETAILS_VIEW (details_view));
 
+  if (details_view->fixed_columns == TRUE)
+    fixed_columns_used = TRUE;
+
+  /* Disable fixed column mode during resize, since it can generate graphical glitches */
+  if (fixed_columns_used)
+      thunar_details_view_set_fixed_columns (details_view, FALSE);
+
   /* determine the list of tree view columns */
   for (column = 0; column < THUNAR_N_VISIBLE_COLUMNS; ++column)
     {
       /* just queue a resize on this column */
       gtk_tree_view_column_queue_resize (details_view->columns[column]);
     }
+
+  if (fixed_columns_used)
+    {
+      /* Call when idle to ensure that gtk_tree_view_column_queue_resize got finished */
+      gdk_threads_add_idle (thunar_details_view_zoom_level_changed_reload_fixed_columns, details_view);
+    }
 }
 
 
@@ -971,6 +997,10 @@ thunar_details_view_set_fixed_columns (ThunarDetailsView *details_view,
       /* apply the new value */
       details_view->fixed_columns = fixed_columns;
 
+      /* disable in reverse order, otherwise graphical glitches can appear*/
+      if (!fixed_columns)
+        gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (gtk_bin_get_child (GTK_BIN (details_view))), FALSE);
+
       /* apply the new setting to all columns */
       for (column = 0; column < THUNAR_N_VISIBLE_COLUMNS; ++column)
         {
@@ -994,9 +1024,9 @@ thunar_details_view_set_fixed_columns (ThunarDetailsView *details_view,
         }
 
       /* for fixed columns mode, we can enable the fixed height
-       * mode to improve the performance of the GtkTreeVeiw.
-       */
-      gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (gtk_bin_get_child (GTK_BIN (details_view))), fixed_columns);
+       * mode to improve the performance of the GtkTreeVeiw. */
+      if (fixed_columns)
+        gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (gtk_bin_get_child (GTK_BIN (details_view))), TRUE);
 
       /* notify listeners */
       g_object_notify (G_OBJECT (details_view), "fixed-columns");
