@@ -421,9 +421,13 @@ thunar_folder_files_ready (ThunarJob    *job,
 static gboolean
 thunar_folder_content_type_loader_idle (gpointer data)
 {
-  ThunarFolder *folder = THUNAR_FOLDER (data);
+  ThunarFolder *folder;
   GList        *lp;
 
+  _thunar_return_val_if_fail (THUNAR_IS_FOLDER (data), FALSE);
+
+  folder = THUNAR_FOLDER (data);
+
   /* load another files content type */
   for (lp = folder->content_type_ptr; lp != NULL; lp = lp->next)
     if (thunar_file_load_content_type (lp->data))
@@ -447,6 +451,8 @@ thunar_folder_content_type_loader_idle (gpointer data)
 static void
 thunar_folder_content_type_loader_idle_destroyed (gpointer data)
 {
+  _thunar_return_if_fail (THUNAR_IS_FOLDER (data));
+
   THUNAR_FOLDER (data)->content_type_idle_id = 0;
 }
 
