@@ -46,6 +46,7 @@ thunar_gtk_action_set_tooltip (GtkAction   *action,
                                const gchar *format,
                                ...)
 {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   va_list var_args;
   gchar  *tooltip;
 
@@ -62,6 +63,7 @@ thunar_gtk_action_set_tooltip (GtkAction   *action,
 
   /* release the tooltip */
   g_free (tooltip);
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 
@@ -80,6 +82,7 @@ thunar_gtk_action_group_set_action_sensitive (GtkActionGroup *action_group,
                                               const gchar    *action_name,
                                               gboolean        sensitive)
 {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   GtkAction *action;
 
   _thunar_return_if_fail (GTK_IS_ACTION_GROUP (action_group));
@@ -90,6 +93,7 @@ thunar_gtk_action_group_set_action_sensitive (GtkActionGroup *action_group,
 
   /* apply the sensitivity to the action */
   gtk_action_set_sensitive (action, sensitive);
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 
@@ -125,54 +129,29 @@ thunar_gtk_label_set_a11y_relation (GtkLabel  *label,
 
 /**
  * thunar_gtk_menu_run:
- * @menu          : a #GtkMenu.
- * @parent        : either a #GtkWidget or a #GdkScreen which determines the screen
- *                  on which to run the @menu. May also be %NULL, which means that
- *                  the screen of @menu will not be altered.
- * @func          : a user supplied function used to position the menu, or %NULL.
- * @data          : user supplied data to be passed to @func.
- * @button        : the mouse button which was pressed to initiate the event.
- * @activate_time : the time at which the activation event occurred.
+ * @menu : a #GtkMenu.
  *
- * A simple wrapper around gtk_menu_popup(), which runs the @menu in a separate
- * main loop and returns only after the @menu was deactivated.
+ * A simple wrapper around gtk_menu_popup_at_pointer(), which takes care on the
+ * menu and returns only after the @menu was deactivated.
  *
  * This method automatically takes over the floating reference of @menu if any and
  * releases it on return. That means if you created the menu via gtk_menu_new() you'll
  * not need to take care of destroying the menu later.
  **/
 void
-thunar_gtk_menu_run (GtkMenu            *menu,
-                     gpointer            parent,
-                     GtkMenuPositionFunc func,
-                     gpointer            data,
-                     guint               button,
-                     guint32             activate_time)
+thunar_gtk_menu_run (GtkMenu *menu)
 {
-  GMainLoop *loop;
-  gulong     signal_id;
+  GdkEvent  *event;
 
-  _thunar_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
   _thunar_return_if_fail (GTK_IS_MENU (menu));
 
   /* take over the floating reference on the menu */
   g_object_ref_sink (G_OBJECT (menu));
 
-  /* place the menu on the same screen as the parent */
-  if (G_UNLIKELY (parent != NULL && GDK_IS_SCREEN (parent)))
-    gtk_menu_set_screen (menu, GDK_SCREEN (parent));
-  else if (G_LIKELY (parent != NULL && GTK_IS_WIDGET (parent)))
-    gtk_menu_set_screen (menu, gtk_widget_get_screen (GTK_WIDGET (parent)));
-
-  /* run an internal main loop */
-  loop = g_main_loop_new (NULL, FALSE);
-  signal_id = g_signal_connect_swapped (G_OBJECT (menu), "deactivate", G_CALLBACK (g_main_loop_quit), loop);
-  gtk_menu_popup (menu, NULL, NULL, func, data, button, activate_time);
-  gtk_grab_add (GTK_WIDGET (menu));
-  g_main_loop_run (loop);
-  g_signal_handler_disconnect (G_OBJECT (menu), signal_id);
-  g_main_loop_unref (loop);
-  gtk_grab_remove (GTK_WIDGET (menu));
+  event = gtk_get_current_event ();
+  gtk_menu_popup_at_pointer (menu, event);
+  gdk_event_free (event);
+  gtk_menu_reposition (menu);
 
   /* release the menu reference */
   g_object_unref (G_OBJECT (menu));
@@ -199,6 +178,7 @@ thunar_gtk_ui_manager_get_action_by_name (GtkUIManager *ui_manager,
   GtkAction *action;
   GList     *lp;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   _thunar_return_val_if_fail (GTK_IS_UI_MANAGER (ui_manager), NULL);
   _thunar_return_val_if_fail (action_name != NULL, NULL);
 
@@ -209,6 +189,7 @@ thunar_gtk_ui_manager_get_action_by_name (GtkUIManager *ui_manager,
       if (G_LIKELY (action != NULL))
         return action;
     }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   return NULL;
 }
