@@ -35,12 +35,7 @@ void             thunar_gtk_action_group_set_action_sensitive (GtkActionGroup
 void             thunar_gtk_label_set_a11y_relation           (GtkLabel           *label,
                                                                GtkWidget          *widget);
 
-void             thunar_gtk_menu_run                          (GtkMenu            *menu,
-                                                               gpointer            parent,
-                                                               GtkMenuPositionFunc func,
-                                                               gpointer            data,
-                                                               guint               button,
-                                                               guint32             activate_time);
+void             thunar_gtk_menu_run                          (GtkMenu            *menu);
 
 GtkAction       *thunar_gtk_ui_manager_get_action_by_name     (GtkUIManager       *ui_manager,
                                                                const gchar        *action_name);
@@ -51,6 +46,70 @@ void             thunar_gtk_widget_set_tooltip                (GtkWidget
 
 GMountOperation *thunar_gtk_mount_operation_new               (gpointer            parent);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
+static inline int
+thunar_gtk_widget_get_allocation_x (GtkWidget *widget)
+{
+    GtkAllocation allocation;
+
+    gtk_widget_get_allocation (widget, &allocation);
+
+    return allocation.x;
+}
+
+static inline int
+thunar_gtk_widget_get_allocation_y (GtkWidget *widget)
+{
+    GtkAllocation allocation;
+
+    gtk_widget_get_allocation (widget, &allocation);
+
+    return allocation.y;
+}
+
+static inline int
+thunar_gtk_widget_get_allocation_width (GtkWidget *widget)
+{
+    GtkAllocation allocation;
+
+    gtk_widget_get_allocation (widget, &allocation);
+
+    return allocation.width;
+}
+
+static inline int
+thunar_gtk_widget_get_allocation_height (GtkWidget *widget)
+{
+    GtkAllocation allocation;
+
+    gtk_widget_get_allocation (widget, &allocation);
+
+    return allocation.height;
+}
+
+static inline int
+thunar_gtk_widget_get_requisition_width (GtkWidget *widget)
+{
+    GtkRequisition requisition;
+
+    gtk_widget_get_requisition (widget, &requisition);
+
+    return requisition.width;
+}
+
+static inline int
+thunar_gtk_widget_get_requisition_height (GtkWidget *widget)
+{
+    GtkRequisition requisition;
+
+    gtk_widget_get_requisition (widget, &requisition);
+
+    return requisition.height;
+}
+
+G_GNUC_END_IGNORE_DEPRECATIONS
+
 G_END_DECLS;
 
 #endif /* !__THUNAR_GTK_EXTENSIONS_H__ */
