@@ -33,46 +33,36 @@
 
 
 static gboolean
-_thunar_misc_jobs_load_templates (ThunarJob   *job,
-                                  GValueArray *param_values,
-                                  GError     **error)
+_thunar_misc_jobs_load_templates (ThunarJob  *job,
+                                  GArray     *param_values,
+                                  GError    **error)
 {
-  ThunarFile *file;
-  GtkWidget  *menu;
-  GFile      *home_dir;
-  GFile      *templates_dir;
-  GList      *files = NULL;
-  GList      *lp;
-  GList      *paths = NULL;
+  GtkWidget   *menu;
+  GFile       *home_dir;
+  GFile       *templates_dir;
+  GList       *files = NULL;
+  const gchar *path;
 
   _thunar_return_val_if_fail (THUNAR_IS_JOB (job), FALSE);
   _thunar_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-  _thunar_return_val_if_fail (param_values != NULL && param_values->n_values == 1, FALSE);
+  _thunar_return_val_if_fail (param_values != NULL && param_values->len == 1, FALSE);
 
-  menu = g_value_get_object (g_value_array_get_nth (param_values, 0));
+  menu = g_value_get_object (&g_array_index (param_values, GValue, 0));
   g_object_set_data (G_OBJECT (job), "menu", menu);
 
   home_dir = thunar_g_file_new_for_home ();
-  templates_dir = thunar_g_file_new_for_user_special_dir (G_USER_DIRECTORY_TEMPLATES);
+  path = g_get_user_special_dir (G_USER_DIRECTORY_TEMPLATES);
+  if (G_LIKELY (path != NULL))
+    templates_dir = g_file_new_for_path (path);
+  else
+    templates_dir = g_file_resolve_relative_path (home_dir, "Templates");
 
   if (G_LIKELY (!g_file_equal (templates_dir, home_dir)))
     {
-      paths = thunar_io_scan_directory (job, templates_dir, 
-                                        G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-                                        TRUE, FALSE, NULL);
-
-      /* turn the GFile list into a ThunarFile list */
-      for (lp = g_list_last (paths); 
-           lp != NULL && !exo_job_is_cancelled (EXO_JOB (job));
-           lp = lp->prev)
-        {
-          file = thunar_file_get (lp->data, NULL);
-          if (G_LIKELY (file != NULL))
-            files = g_list_prepend (files, file);
-        }
-
-      /* free the GFile list */
-      thunar_g_file_list_free (paths);
+      /* load the ThunarFiles */
+      files = thunar_io_scan_directory (job, templates_dir,
+                                        G_FILE_QUERY_INFO_NONE, /* symlink ok */
+                                        TRUE, FALSE, TRUE, NULL);
     }
 
   g_object_unref (templates_dir);
@@ -80,7 +70,7 @@ _thunar_misc_jobs_load_templates (ThunarJob   *job,
 
   if (files == NULL || exo_job_is_cancelled (EXO_JOB (job)))
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND, 
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
                    _("No templates installed"));
 
       return FALSE;
@@ -88,7 +78,7 @@ _thunar_misc_jobs_load_templates (ThunarJob   *job,
   else
     {
       if (!thunar_job_files_ready (job, files))
-        thunar_file_list_free (files);
+        thunar_g_file_list_free (files);
 
       return TRUE;
     }
