@@ -35,17 +35,17 @@
 
 #include <thunar/thunar-application.h>
 #include <thunar/thunar-browser.h>
+#include <thunar/thunar-device-monitor.h>
 #include <thunar/thunar-dialogs.h>
 #include <thunar/thunar-dnd.h>
 #include <thunar/thunar-gio-extensions.h>
 #include <thunar/thunar-gtk-extensions.h>
+#include <thunar/thunar-menu-util.h>
 #include <thunar/thunar-preferences.h>
 #include <thunar/thunar-private.h>
 #include <thunar/thunar-shortcuts-icon-renderer.h>
 #include <thunar/thunar-shortcuts-model.h>
 #include <thunar/thunar-shortcuts-view.h>
-#include <thunar/thunar-device-monitor.h>
-#include <thunar/thunar-stock.h>
 
 
 
@@ -269,7 +269,7 @@ thunar_shortcuts_view_class_init (ThunarShortcutsViewClass *klass)
 static void
 thunar_shortcuts_view_init (ThunarShortcutsView *view)
 {
-  GtkTreeViewColumn *column;
+  GtkTreeViewColumn *column, *column_eject;
   GtkCellRenderer   *renderer;
   GtkTreeSelection  *selection;
 
@@ -291,11 +291,15 @@ thunar_shortcuts_view_init (ThunarShortcutsView *view)
   column = g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
                          "reorderable", FALSE,
                          "resizable", FALSE,
+                         "expand", TRUE,
                          "sizing", GTK_TREE_VIEW_COLUMN_AUTOSIZE,
                          "spacing", 2,
                          NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
 
+  column_eject = gtk_tree_view_column_new ();
+  gtk_tree_view_append_column (GTK_TREE_VIEW (view), column_eject);
+
   /* queue a resize on the column whenever the icon size is changed */
   view->queue_resize_signal_id = g_signal_connect_swapped (G_OBJECT (view->preferences), "notify::shortcuts-icon-size",
                                                            G_CALLBACK (gtk_tree_view_column_queue_resize), column);
@@ -304,7 +308,8 @@ thunar_shortcuts_view_init (ThunarShortcutsView *view)
   renderer = g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
                            "weight", PANGO_WEIGHT_BOLD,
                            "xpad", 6,
-                           "ypad", 6,
+                           "ypad", 4,
+                           "ellipsize", PANGO_ELLIPSIZE_END,
                            NULL);
   gtk_tree_view_column_pack_start (column, renderer, FALSE);
   gtk_tree_view_column_set_attributes (column, renderer,
@@ -349,8 +354,8 @@ thunar_shortcuts_view_init (ThunarShortcutsView *view)
 
   /* spinner to indicate (un)mount/eject delay */
   renderer = gtk_cell_renderer_spinner_new ();
-  gtk_tree_view_column_pack_start (column, renderer, FALSE);
-  gtk_tree_view_column_set_attributes (column, renderer,
+  gtk_tree_view_column_pack_start (column_eject, renderer, FALSE);
+  gtk_tree_view_column_set_attributes (column_eject, renderer,
                                        "visible", THUNAR_SHORTCUTS_MODEL_COLUMN_BUSY,
                                        "active", THUNAR_SHORTCUTS_MODEL_COLUMN_BUSY,
                                        "pulse", THUNAR_SHORTCUTS_MODEL_COLUMN_BUSY_PULSE,
@@ -359,8 +364,8 @@ thunar_shortcuts_view_init (ThunarShortcutsView *view)
   /* allocate icon renderer for the eject symbol */
   renderer = gtk_cell_renderer_pixbuf_new ();
   g_object_set (renderer, "mode", GTK_CELL_RENDERER_MODE_ACTIVATABLE, "icon-name", "media-eject", NULL);
-  gtk_tree_view_column_pack_start (column, renderer, FALSE);
-  gtk_tree_view_column_set_attributes (column, renderer,
+  gtk_tree_view_column_pack_start (column_eject, renderer, FALSE);
+  gtk_tree_view_column_set_attributes (column_eject, renderer,
                                        "visible", THUNAR_SHORTCUTS_MODEL_COLUMN_CAN_EJECT,
                                        NULL);
 
@@ -449,7 +454,7 @@ thunar_shortcuts_view_button_press_event (GtkWidget      *widget,
           /* check if we clicked the eject button area */
           column_width = gtk_tree_view_column_get_width (gtk_tree_view_get_column (GTK_TREE_VIEW (view), 0));
           gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &icon_width, &icon_height);
-          if (event->button == 1 && event->x >= column_width - icon_width - 3)
+          if (event->button == 1 && event->x > column_width)
             {
               /* check if that shortcut actually has an eject button */
               model = gtk_tree_view_get_model (GTK_TREE_VIEW (view));
@@ -533,10 +538,10 @@ thunar_shortcuts_view_key_release_event (GtkWidget   *widget,
   /* work nicer with keyboard navigation */
   switch (event->keyval)
     {
-    case GDK_Up:
-    case GDK_Down:
-    case GDK_KP_Up:
-    case GDK_KP_Down:
+    case GDK_KEY_Up:
+    case GDK_KEY_Down:
+    case GDK_KEY_KP_Up:
+    case GDK_KEY_KP_Down:
       thunar_shortcuts_view_open (view, OPEN_IN_VIEW);
 
       /* keep focus on us */
@@ -591,8 +596,8 @@ thunar_shortcuts_view_drag_data_received (GtkWidget        *widget,
   if (G_LIKELY (!view->drop_data_ready))
     {
       /* extract the URI list from the selection data (if valid) */
-      if (info == TEXT_URI_LIST && selection_data->format == 8 && selection_data->length > 0)
-        view->drop_file_list = thunar_g_file_list_new_from_string ((const gchar *) selection_data->data);
+      if (info == TEXT_URI_LIST && gtk_selection_data_get_format (selection_data) == 8 && gtk_selection_data_get_length (selection_data) > 0)
+        view->drop_file_list = thunar_g_file_list_new_from_string ((const gchar *) gtk_selection_data_get_data (selection_data));
 
       /* reset the state */
       view->drop_data_ready = TRUE;
@@ -637,7 +642,7 @@ thunar_shortcuts_view_drag_data_received (GtkWidget        *widget,
                         {
                           /* ask the user what to do with the drop data */
                           if (G_UNLIKELY (action == GDK_ACTION_ASK))
-                            action = thunar_dnd_ask (widget, file, view->drop_file_list, timestamp, actions);
+                            action = thunar_dnd_ask (widget, file, view->drop_file_list, actions);
 
                           /* perform the requested action */
                           if (G_LIKELY (action != 0))
@@ -793,11 +798,11 @@ thunar_shortcuts_view_drag_motion (GtkWidget      *widget,
   else if (target == gdk_atom_intern_static_string ("GTK_TREE_MODEL_ROW"))
     {
       /* check the action that should be performed */
-      if (context->suggested_action == GDK_ACTION_LINK || (context->actions & GDK_ACTION_LINK) != 0)
+      if (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_LINK || (gdk_drag_context_get_actions (context) & GDK_ACTION_LINK) != 0)
         action = GDK_ACTION_LINK;
-      else if (context->suggested_action == GDK_ACTION_COPY || (context->actions & GDK_ACTION_COPY) != 0)
+      else if (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_COPY || (gdk_drag_context_get_actions (context) & GDK_ACTION_COPY) != 0)
         action = GDK_ACTION_COPY;
-      else if (context->suggested_action == GDK_ACTION_MOVE || (context->actions & GDK_ACTION_MOVE) != 0)
+      else if (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_MOVE || (gdk_drag_context_get_actions (context) & GDK_ACTION_MOVE) != 0)
         action = GDK_ACTION_MOVE;
       else
         return FALSE;
@@ -1035,10 +1040,8 @@ thunar_shortcuts_view_context_menu_visibility (ThunarShortcutsView *view,
 
   gtk_tree_path_free (path);
 
-  /* run the menu on the view's screen (taking over the floating reference on menu) */
-  thunar_gtk_menu_run (GTK_MENU (menu), GTK_WIDGET (view), NULL, NULL,
-                       (event != NULL) ? event->button : 0,
-                       (event != NULL) ? event->time : gtk_get_current_event_time ());
+  /* run the menu (taking over the floating reference on menu) */
+  thunar_gtk_menu_run (GTK_MENU (menu));
 }
 
 
@@ -1058,7 +1061,7 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
   gboolean             mutable;
   ThunarDevice        *device;
   GList               *providers, *lp;
-  GList               *actions = NULL, *tmp;
+  GList               *items = NULL, *tmp;
   ThunarShortcutGroup  group;
   gboolean             is_header;
   GFile               *mount_point;
@@ -1092,23 +1095,31 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
   menu = gtk_menu_new ();
 
   /* append the "Open" menu action */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   item = gtk_image_menu_item_new_with_mnemonic (_("_Open"));
+G_GNUC_END_IGNORE_DEPRECATIONS
   g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_open_clicked), view);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   gtk_widget_show (item);
 
-  /* set the stock icon */
-  image = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
+  /* set the icon */
+  image = gtk_image_new_from_icon_name ("document-open", GTK_ICON_SIZE_MENU);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
-  
+G_GNUC_END_IGNORE_DEPRECATIONS
+
   /* append the "Open in New Tab" menu action */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   item = gtk_image_menu_item_new_with_mnemonic (_("Open in New Tab"));
+G_GNUC_END_IGNORE_DEPRECATIONS
   g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_open_in_new_tab_clicked), view);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   gtk_widget_show (item);
 
   /* append the "Open in New Window" menu action */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   item = gtk_image_menu_item_new_with_mnemonic (_("Open in New Window"));
+G_GNUC_END_IGNORE_DEPRECATIONS
   g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_open_in_new_window_clicked), view);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   gtk_widget_show (item);
@@ -1129,19 +1140,25 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
         gtk_widget_show (item);
 
         /* append the "Mount" item */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         item = gtk_image_menu_item_new_with_mnemonic (_("_Mount"));
+G_GNUC_END_IGNORE_DEPRECATIONS
         gtk_widget_set_visible (item, can_mount);
         g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_mount), view);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
         /* append the "Unmount" item */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         item = gtk_image_menu_item_new_with_mnemonic (_("_Unmount"));
+G_GNUC_END_IGNORE_DEPRECATIONS
         gtk_widget_set_visible (item, can_unmount);
         g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_unmount), view);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
         /* append the "Disconnect" (eject + safely remove drive) item */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         item = gtk_image_menu_item_new_with_mnemonic (_("_Eject"));
+G_GNUC_END_IGNORE_DEPRECATIONS
         gtk_widget_set_visible (item, can_eject);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
         g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_eject), view);
@@ -1158,14 +1175,18 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
         shortcuts_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
 
         /* append the "Disconnect" item */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         item = gtk_image_menu_item_new_with_mnemonic (_("Create _Shortcut"));
+G_GNUC_END_IGNORE_DEPRECATIONS
         gtk_widget_set_sensitive (item, mount_point != NULL && !thunar_shortcuts_model_has_bookmark (THUNAR_SHORTCUTS_MODEL (shortcuts_model), mount_point));
         g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_create_shortcut), view);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
         gtk_widget_show (item);
 
-        image = gtk_image_new_from_stock (THUNAR_STOCK_SHORTCUTS, GTK_ICON_SIZE_MENU);
+        image = gtk_image_new_from_icon_name ("stock_thunar-shortcuts", GTK_ICON_SIZE_MENU);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
         if (mount_point != NULL)
           g_object_unref (mount_point);
@@ -1179,14 +1200,19 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
         gtk_widget_show (item);
 
         /* append the "Disconnect" item */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         item = gtk_image_menu_item_new_with_mnemonic (_("Disconn_ect"));
+G_GNUC_END_IGNORE_DEPRECATIONS
         gtk_widget_set_sensitive (item, thunar_device_can_eject (device));
         g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_eject), view);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
         gtk_widget_show (item);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+        /* TODO: Drop this icon or add a custom one as above (shortcut) */
         image = gtk_image_new_from_stock (GTK_STOCK_DISCONNECT, GTK_ICON_SIZE_MENU);
         gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+G_GNUC_END_IGNORE_DEPRECATIONS
         break;
 
       case THUNAR_SHORTCUT_GROUP_PLACES_TRASH:
@@ -1196,7 +1222,9 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
         gtk_widget_show (item);
 
         /* append the "Empty Trash" menu action */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         item = gtk_image_menu_item_new_with_mnemonic (_("_Empty Trash"));
+G_GNUC_END_IGNORE_DEPRECATIONS
         gtk_widget_set_sensitive (item, (thunar_file_get_item_count (file) > 0));
         g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_empty_trash), view);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
@@ -1217,16 +1245,16 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
           /* determine the toplevel window we belong to */
           window = gtk_widget_get_toplevel (GTK_WIDGET (view));
 
-          /* load the actions offered by the menu providers */
+          /* load the menu items offered by the menu providers */
           for (lp = providers; lp != NULL; lp = lp->next)
             {
-              tmp = thunarx_menu_provider_get_folder_actions (lp->data, window, THUNARX_FILE_INFO (file));
-              actions = g_list_concat (actions, tmp);
+              tmp = thunarx_menu_provider_get_folder_menu_items (lp->data, window, THUNARX_FILE_INFO (file));
+              items = g_list_concat (items, tmp);
               g_object_unref (G_OBJECT (lp->data));
             }
           g_list_free (providers);
 
-          if (actions != NULL)
+          if (items != NULL)
             {
               /* append a menu separator */
               item = gtk_separator_menu_item_new ();
@@ -1234,19 +1262,11 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
               gtk_widget_show (item);
             }
 
-          /* add the actions to the menu */
-          for (lp = actions; lp != NULL; lp = lp->next)
-            {
-              item = gtk_action_create_menu_item (GTK_ACTION (lp->data));
-              gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-              gtk_widget_show (item);
-
-              /* release the reference on the action */
-              g_object_unref (G_OBJECT (lp->data));
-            }
+          /* add the menu items to the menu */
+          thunar_menu_util_add_items_to_menu (menu, items);
 
           /* cleanup */
-          g_list_free (actions);
+          g_list_free (items);
         }
     }
 
@@ -1258,7 +1278,9 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
       gtk_widget_show (item);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       item = gtk_image_menu_item_new_with_mnemonic (_("_Remove Shortcut"));
+G_GNUC_END_IGNORE_DEPRECATIONS
       g_object_set_data_full (G_OBJECT (item), I_("thunar-shortcuts-row"),
                               gtk_tree_row_reference_new (model, path),
                               (GDestroyNotify) gtk_tree_row_reference_free);
@@ -1267,12 +1289,16 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
       gtk_widget_show (item);
 
-      /* set the remove stock icon */
-      image = gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU);
+      /* set the remove icon */
+      image = gtk_image_new_from_icon_name ("list-remove", GTK_ICON_SIZE_MENU);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
       /* append the rename menu item */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       item = gtk_image_menu_item_new_with_mnemonic (_("Re_name Shortcut"));
+G_GNUC_END_IGNORE_DEPRECATIONS
       g_object_set_data_full (G_OBJECT (item), I_("thunar-shortcuts-row"),
                               gtk_tree_row_reference_new (model, path),
                               (GDestroyNotify) gtk_tree_row_reference_free);
@@ -1290,9 +1316,8 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
     g_object_unref (G_OBJECT (device));
   gtk_tree_path_free (path);
 
-  /* run the menu on the view's screen (taking over the floating reference on menu) */
-  thunar_gtk_menu_run (GTK_MENU (menu), GTK_WIDGET (view), NULL, NULL, (event != NULL) ? event->button : 0,
-                       (event != NULL) ? event->time : gtk_get_current_event_time ());
+  /* run the menu (taking over the floating reference on menu) */
+  thunar_gtk_menu_run (GTK_MENU (menu));
 }
 
 
@@ -1457,11 +1482,11 @@ thunar_shortcuts_view_compute_drop_actions (ThunarShortcutsView     *view,
   if (G_UNLIKELY (actions == 0))
     {
       /* check the action that should be performed */
-      if (context->suggested_action == GDK_ACTION_LINK || (context->actions & GDK_ACTION_LINK) != 0)
+      if (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_LINK || (gdk_drag_context_get_actions (context) & GDK_ACTION_LINK) != 0)
         actions = GDK_ACTION_LINK;
-      else if (context->suggested_action == GDK_ACTION_COPY || (context->actions & GDK_ACTION_COPY) != 0)
+      else if (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_COPY || (gdk_drag_context_get_actions (context) & GDK_ACTION_COPY) != 0)
         actions = GDK_ACTION_COPY;
-      else if (context->suggested_action == GDK_ACTION_MOVE || (context->actions & GDK_ACTION_MOVE) != 0)
+      else if (gdk_drag_context_get_suggested_action (context) == GDK_ACTION_MOVE || (gdk_drag_context_get_actions (context) & GDK_ACTION_MOVE) != 0)
         actions = GDK_ACTION_MOVE;
       else
         return 0;
@@ -1636,7 +1661,7 @@ thunar_shortcuts_view_poke_file_finish (ThunarBrowser *browser,
           /* open a new window for the target folder */
           application = thunar_application_get ();
           thunar_application_open_window (application, target_file,
-                                          gtk_widget_get_screen (GTK_WIDGET (browser)), NULL);
+                                          gtk_widget_get_screen (GTK_WIDGET (browser)), NULL, TRUE);
           g_object_unref (application);
         }
       else if (open_in == OPEN_IN_TAB)
@@ -1692,7 +1717,8 @@ thunar_shortcuts_view_poke_device_finish (ThunarBrowser *browser,
                                           ThunarDevice  *device,
                                           ThunarFile    *mount_point,
                                           GError        *error,
-                                          gpointer       user_data)
+                                          gpointer       user_data,
+                                          gboolean       cancelled)
 {
   gchar        *device_name;
   GtkTreeModel *model;
@@ -1701,7 +1727,11 @@ thunar_shortcuts_view_poke_device_finish (ThunarBrowser *browser,
   _thunar_return_if_fail (THUNAR_IS_SHORTCUTS_VIEW (browser));
   _thunar_return_if_fail (THUNAR_IS_DEVICE (device));
 
-  if (error == NULL)
+  if (cancelled)
+    {
+      /* do nothing */
+    }
+  else if (error == NULL)
     {
       thunar_browser_poke_file (browser, mount_point, GTK_WIDGET (browser),
                                 thunar_shortcuts_view_poke_file_finish,
@@ -1990,7 +2020,7 @@ thunar_shortcuts_view_mount (ThunarShortcutsView *view)
           thunar_shortcuts_model_set_busy (THUNAR_SHORTCUTS_MODEL (child_model), device, TRUE);
 
           thunar_browser_poke_device (THUNAR_BROWSER (view), device, view,
-                                      thunar_shortcuts_view_poke_device_mount_finish,
+                                      (ThunarBrowserPokeDeviceFunc)thunar_shortcuts_view_poke_device_mount_finish,
                                       NULL);
           g_object_unref (device);
         }
@@ -2135,5 +2165,3 @@ thunar_shortcuts_view_select_by_file (ThunarShortcutsView *view,
   else
      gtk_tree_selection_unselect_all (selection);
 }
-
-
