@@ -71,7 +71,9 @@ static guint templates_action_signals[LAST_SIGNAL];
 
 
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 G_DEFINE_TYPE (ThunarTemplatesAction, thunar_templates_action, GTK_TYPE_ACTION)
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 
 
@@ -84,8 +86,10 @@ thunar_templates_action_class_init (ThunarTemplatesActionClass *klass)
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = thunar_templates_action_finalize;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   gtkaction_class = GTK_ACTION_CLASS (klass);
   gtkaction_class->create_menu_item = thunar_templates_action_create_menu_item;
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   /**
    * ThunarTemplatesAction::create-empty-file:
@@ -157,7 +161,9 @@ thunar_templates_action_create_menu_item (GtkAction *action)
   _thunar_return_val_if_fail (THUNAR_IS_TEMPLATES_ACTION (action), NULL);
 
   /* let GtkAction allocate the menu item */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   item = (*GTK_ACTION_CLASS (thunar_templates_action_parent_class)->create_menu_item) (action);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
   /* associate an empty submenu with the item (will be filled when shown) */
   menu = gtk_menu_new ();
@@ -182,12 +188,12 @@ item_activated (GtkWidget             *item,
   file = g_object_get_data (G_OBJECT (item), I_("thunar-file"));
   if (G_UNLIKELY (file != NULL))
     {
-      g_signal_emit (G_OBJECT (templates_action), 
+      g_signal_emit (G_OBJECT (templates_action),
                      templates_action_signals[CREATE_TEMPLATE], 0, file);
     }
   else
     {
-      g_signal_emit (G_OBJECT (templates_action), 
+      g_signal_emit (G_OBJECT (templates_action),
                      templates_action_signals[CREATE_EMPTY_FILE], 0);
     }
 }
@@ -212,8 +218,8 @@ find_parent_menu (ThunarFile *file,
     return NULL;
 
   /* iterate over all dirs and menu items */
-  for (lp = g_list_first (dirs), ip = g_list_first (items); 
-       parent_menu == NULL && lp != NULL && ip != NULL; 
+  for (lp = g_list_first (dirs), ip = g_list_first (items);
+       parent_menu == NULL && lp != NULL && ip != NULL;
        lp = lp->next, ip = ip->next)
     {
       /* check if the current dir/item is the parent of our file */
@@ -247,14 +253,14 @@ compare_files (ThunarFile *a,
   /* check whether the files are equal */
   if (g_file_equal (file_a, file_b))
     return 0;
-  
+
   /* directories always come first */
-  if (thunar_file_get_kind (a) == G_FILE_TYPE_DIRECTORY 
+  if (thunar_file_get_kind (a) == G_FILE_TYPE_DIRECTORY
       && thunar_file_get_kind (b) != G_FILE_TYPE_DIRECTORY)
     {
       return -1;
     }
-  else if (thunar_file_get_kind (a) != G_FILE_TYPE_DIRECTORY 
+  else if (thunar_file_get_kind (a) != G_FILE_TYPE_DIRECTORY
            && thunar_file_get_kind (b) == G_FILE_TYPE_DIRECTORY)
     {
       return 1;
@@ -321,6 +327,7 @@ thunar_templates_action_files_ready (ThunarJob             *job,
   GList             *items = NULL;
   GList             *parent_menus = NULL;
   GList             *pp;
+  GList             *menu_children = NULL;
   gchar             *label;
   gchar             *dot;
 
@@ -334,14 +341,14 @@ thunar_templates_action_files_ready (ThunarJob             *job,
   /* get the icon factory */
   icon_factory = thunar_icon_factory_get_default ();
 
-  /* sort items so that directories come before files and ancestors come 
+  /* sort items so that directories come before files and ancestors come
    * before descendants */
   files = g_list_sort (files, (GCompareFunc) compare_files);
 
   for (lp = g_list_first (files); lp != NULL; lp = lp->next)
     {
       file = lp->data;
-      
+
       /* determine the parent menu for this file/directory */
       parent_menu = find_parent_menu (file, dirs, items);
       parent_menu = parent_menu == NULL ? menu : parent_menu;
@@ -354,10 +361,12 @@ thunar_templates_action_files_ready (ThunarJob             *job,
           gtk_menu_set_screen (GTK_MENU (submenu), gtk_widget_get_screen (menu));
 
           /* allocate a new menu item for the directory */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
           item = gtk_image_menu_item_new_with_label (thunar_file_get_display_name (file));
+G_GNUC_END_IGNORE_DEPRECATIONS
           gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
 
-          /* prepend the directory, its item and the parent menu it should 
+          /* prepend the directory, its item and the parent menu it should
            * later be added to to the respective lists */
           dirs = g_list_prepend (dirs, file);
           items = g_list_prepend (items, item);
@@ -372,10 +381,12 @@ thunar_templates_action_files_ready (ThunarJob             *job,
             *dot = '\0';
 
           /* allocate a new menu item */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
           item = gtk_image_menu_item_new_with_label (label);
-          g_object_set_data_full (G_OBJECT (item), I_("thunar-file"), 
+G_GNUC_END_IGNORE_DEPRECATIONS
+          g_object_set_data_full (G_OBJECT (item), I_("thunar-file"),
                                   g_object_ref (file), g_object_unref);
-          g_signal_connect (item, "activate", G_CALLBACK (item_activated), 
+          g_signal_connect (item, "activate", G_CALLBACK (item_activated),
                             templates_action);
           gtk_menu_shell_append (GTK_MENU_SHELL (parent_menu), item);
           gtk_widget_show (item);
@@ -390,21 +401,24 @@ thunar_templates_action_files_ready (ThunarJob             *job,
 
       /* allocate an image based on the icon */
       image = gtk_image_new_from_pixbuf (icon);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
       /* release the icon reference */
       g_object_unref (icon);
     }
 
   /* add all non-empty directory items to their parent menu */
-  for (lp = items, pp = parent_menus; 
-       lp != NULL && pp != NULL; 
+  for (lp = items, pp = parent_menus;
+       lp != NULL && pp != NULL;
        lp = lp->next, pp = pp->next)
     {
       /* determine the submenu for this directory item */
       submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (lp->data));
+      menu_children = gtk_container_get_children (GTK_CONTAINER (submenu));
 
-      if (GTK_MENU_SHELL (submenu)->children == NULL)
+      if (menu_children == NULL)
         {
           /* the directory submenu is empty, destroy it */
           gtk_widget_destroy (lp->data);
@@ -421,6 +435,7 @@ thunar_templates_action_files_ready (ThunarJob             *job,
   g_list_free (dirs);
   g_list_free (items);
   g_list_free (parent_menus);
+  g_list_free (menu_children);
 
   /* release the icon factory */
   g_object_unref (icon_factory);
@@ -438,6 +453,7 @@ thunar_templates_action_load_error (ThunarJob             *job,
 {
   GtkWidget *item;
   GtkWidget *menu;
+  GList     *menu_children = NULL;
 
   _thunar_return_if_fail (THUNAR_IS_JOB (job));
   _thunar_return_if_fail (error != NULL);
@@ -447,7 +463,7 @@ thunar_templates_action_load_error (ThunarJob             *job,
   menu = g_object_get_data (G_OBJECT (job), "menu");
 
   /* check if any items were added to the menu */
-  if (G_LIKELY (menu != NULL && GTK_MENU_SHELL (menu)->children == NULL))
+  if (G_LIKELY (menu != NULL && (menu_children = gtk_container_get_children( GTK_CONTAINER (menu))) == NULL))
     {
       /* tell the user that no templates were found */
       item = gtk_menu_item_new_with_label (error->message);
@@ -455,6 +471,8 @@ thunar_templates_action_load_error (ThunarJob             *job,
       gtk_widget_set_sensitive (item, FALSE);
       gtk_widget_show (item);
     }
+
+  g_list_free (menu_children);
 }
 
 
@@ -463,7 +481,6 @@ static void
 thunar_templates_action_load_finished (ThunarJob             *job,
                                        ThunarTemplatesAction *templates_action)
 {
-  GtkWidget *image;
   GtkWidget *item;
   GtkWidget *menu;
 
@@ -480,15 +497,11 @@ thunar_templates_action_load_finished (ThunarJob             *job,
       gtk_widget_show (item);
 
       /* add the "Empty File" item */
-      item = gtk_image_menu_item_new_with_mnemonic (_("_Empty File"));
-      g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (item_activated), 
+      item = gtk_menu_item_new_with_mnemonic (_("_Empty File"));
+      g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (item_activated),
                         templates_action);
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
       gtk_widget_show (item);
-
-      /* add the icon for the emtpy file item */
-      image = gtk_image_new_from_stock (GTK_STOCK_FILE, GTK_ICON_SIZE_MENU);
-      gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
     }
 
   g_signal_handlers_disconnect_matched (job, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL,
@@ -518,13 +531,13 @@ thunar_templates_action_menu_shown (GtkWidget             *menu,
                                  (gpointer) &templates_action->job);
 
       g_signal_connect (templates_action->job, "files-ready",
-                        G_CALLBACK (thunar_templates_action_files_ready), 
+                        G_CALLBACK (thunar_templates_action_files_ready),
                         templates_action);
       g_signal_connect (templates_action->job, "error",
-                        G_CALLBACK (thunar_templates_action_load_error), 
+                        G_CALLBACK (thunar_templates_action_load_error),
                         templates_action);
       g_signal_connect (templates_action->job, "finished",
-                        G_CALLBACK (thunar_templates_action_load_finished), 
+                        G_CALLBACK (thunar_templates_action_load_finished),
                         templates_action);
     }
 }
